==> members-facade-1.0.0-vg-20210506.082713-69-sources.jar: com/bizvane/members/facade/service/api/MemberOrderApiService.java <==
package com.bizvane.members.facade.service.api;

import com.alibaba.fastjson.JSONObject;
import com.bizvane.members.facade.exception.MemberException;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.models.OrderEvaluateModel;
import com.bizvane.members.facade.models.OrderModel;
import com.bizvane.members.facade.vo.OrderApiVo;
import com.bizvane.members.facade.vo.OrderDetailVo;
import com.bizvane.members.facade.vo.OrderModelPageVo;
import com.bizvane.members.facade.vo.SkuSalesDetailVo;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @Author: houkai
 * @Date: 2018/8/3 15:19
 * @Description:
 */
@FeignClient(value = "${feign.client.members.name}", path = "${feign.client.members.path}")
public interface MemberOrderApiService {
    /**
     * 查询会员订单列表
     *
     * @param orderModel
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderList", method = RequestMethod.POST)
    ResponseData<PageInfo<OrderModel>> queryOrderList(@RequestBody OrderApiVo orderApiVo) throws MemberException;

    /**
     * 查询订单详情
     *
     * @param orderModel
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderInfo", method = RequestMethod.POST)
    ResponseData<OrderModel> queryOrderInfo(@RequestBody OrderModel orderModel) throws MemberException;

    /**
     * 评价订单
     *
     * @param orderEvaluateModel
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/addOrderEvaluate", method = RequestMethod.POST)
    ResponseData addOrderEvaluate(@RequestBody OrderEvaluateModel orderEvaluateModel) throws MemberException;

    /**
     * 查询订单评价详情
     *
     * @param orderNo
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderEvaluateInfo", method = RequestMethod.POST)
    ResponseData<OrderEvaluateModel> queryOrderEvaluateInfo(@RequestParam("orderNo") String orderNo,@RequestParam("sysBrandId") Long sysBrandId) throws MemberException;

    /**
     * 上传订单评价图片
     *
     * @param currentMember
     * @return
     */
    @RequestMapping(value = "/api/memberOrder/uploadEvaluatePic", method = RequestMethod.POST)
    ResponseData<JSONObject> uploadEvaluatePic(@RequestBody MemberInfoModel currentMember) throws MemberException;

    /**
     * 查询订单商品编号
     *
     * @param orderNo
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderProductNo", method = RequestMethod.POST)
    ResponseData<String> queryOrderProductNo(@RequestParam("orderNo") String orderNo) throws MemberException;


    @RequestMapping(value = "/api/memberOrder/queryOrderModel", method = RequestMethod.POST)
    ResponseData<OrderModel> queryOrderModel(@RequestParam("orderNo") String orderNo, @RequestParam("brandId") Long brandId);

    /**
     * 根据店铺id或导购id 和时间 查询订单
     * @param orderModelPage
     * @return
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderModelByStore", method = RequestMethod.POST)
    ResponseData<SkuSalesDetailVo> queryOrderModelByStore(@RequestBody OrderModelPageVo orderModelPage);

    /**
     *根据订单号查询对应的核销人的会员信息
     */
    @RequestMapping(value = "/api/memberOrder/queryMemberInfoByOrderNo", method = RequestMethod.POST)
    ResponseData<MemberInfoModel> queryMemberInfoByOrderNo(@RequestBody OrderModel orderModel);

    /**
     *根据订单号查询对应的核销人的会员信息
     */
    @RequestMapping(value = "/api/memberOrder/insert", method = RequestMethod.POST)
    ResponseData insert(@RequestBody OrderModel orderModel) throws MemberException;

    /**
     * 修改订单获得积分（361积分计算后修改）
     * @param orderModel
     * @return
     */
    @RequestMapping(value = "/api/memberOrder/updateOrderGetedIntegral", method = RequestMethod.POST)
    ResponseData updateOrderGetedIntegral(@RequestBody OrderModel orderModel);
    /**
     * 根据订单编号获取订单详情
     * @param orderNo
     * @param sysCompanyId
     * @param brandId
     * @return
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderDetailByOrderNo", method = RequestMethod.POST)
    ResponseData<List<OrderDetailVo>> queryOrderDetailVoByOrderNo(@RequestParam("orderNo") String orderNo, @RequestParam("sysCompanyId") Long sysCompanyId, @RequestParam("brandId") Long brandId);

}

==> members-facade-1.5.4-vg-0928-20220928.113110-9-sources.jar: com/bizvane/members/facade/service/api/MemberOrderApiService.java <==
package com.bizvane.members.facade.service.api;

import com.alibaba.fastjson.JSONObject;
import com.bizvane.members.facade.exception.MemberException;
import com.bizvane.members.facade.models.MemberInfoModel;
import com.bizvane.members.facade.models.OrderEvaluateModel;
import com.bizvane.members.facade.models.OrderModel;
import com.bizvane.members.facade.vo.OrderApiVo;
import com.bizvane.members.facade.vo.OrderDetailVo;
import com.bizvane.members.facade.vo.OrderModelPageVo;
import com.bizvane.members.facade.vo.SkuSalesDetailVo;
import com.bizvane.utils.responseinfo.PageInfo;
import com.bizvane.utils.responseinfo.ResponseData;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

/**
 * @Author: houkai
 * @Date: 2018/8/3 15:19
 * @Description:
 */
@FeignClient(value = "${feign.client.members.name}", path = "${feign.client.members.path}")
public interface MemberOrderApiService {
    /**
     * 查询会员订单列表
     *
     * @param orderModel
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderList", method = RequestMethod.POST)
    ResponseData<PageInfo<OrderModel>> queryOrderList(@RequestBody OrderApiVo orderApiVo) throws MemberException;

    /**
     * 查询会员订单详情列表
     *
     * @param orderApiVo
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderDetailList", method = RequestMethod.POST)
    ResponseData<PageInfo<OrderModel>> queryOrderDetailList(@RequestBody OrderApiVo orderApiVo) throws MemberException;


    /**
     * 查询订单详情
     *
     * @param orderModel
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderInfo", method = RequestMethod.POST)
    ResponseData<OrderModel> queryOrderInfo(@RequestBody OrderModel orderModel) throws MemberException;

    /**
     * 评价订单
     *
     * @param orderEvaluateModel
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/addOrderEvaluate", method = RequestMethod.POST)
    ResponseData addOrderEvaluate(@RequestBody OrderEvaluateModel orderEvaluateModel) throws MemberException;

    /**
     * 查询订单评价详情
     *
     * @param orderNo
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderEvaluateInfo", method = RequestMethod.POST)
    ResponseData<OrderEvaluateModel> queryOrderEvaluateInfo(@RequestParam("orderNo") String orderNo,@RequestParam("sysBrandId") Long sysBrandId) throws MemberException;

    /**
     * 上传订单评价图片
     *
     * @param currentMember
     * @return
     */
    @RequestMapping(value = "/api/memberOrder/uploadEvaluatePic", method = RequestMethod.POST)
    ResponseData<JSONObject> uploadEvaluatePic(@RequestBody MemberInfoModel currentMember) throws MemberException;

    /**
     * 查询订单商品编号
     *
     * @param orderNo
     * @return
     * @throws MemberException
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderProductNo", method = RequestMethod.POST)
    ResponseData<String> queryOrderProductNo(@RequestParam("orderNo") String orderNo) throws MemberException;


    @RequestMapping(value = "/api/memberOrder/queryOrderModel", method = RequestMethod.POST)
    ResponseData<OrderModel> queryOrderModel(@RequestParam("orderNo") String orderNo, @RequestParam("brandId") Long brandId);

    /**
     * 根据店铺id或导购id 和时间 查询订单
     * @param orderModelPage
     * @return
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderModelByStore", method = RequestMethod.POST)
    ResponseData<SkuSalesDetailVo> queryOrderModelByStore(@RequestBody OrderModelPageVo orderModelPage);

    /**
     *根据订单号查询对应的核销人的会员信息
     */
    @RequestMapping(value = "/api/memberOrder/queryMemberInfoByOrderNo", method = RequestMethod.POST)
    ResponseData<MemberInfoModel> queryMemberInfoByOrderNo(@RequestBody OrderModel orderModel);

    /**
     *根据订单号查询对应的核销人的会员信息
     */
    @RequestMapping(value = "/api/memberOrder/insert", method = RequestMethod.POST)
    ResponseData insert(@RequestBody OrderModel orderModel) throws MemberException;

    /**
     * 修改订单获得积分（361积分计算后修改）
     * @param orderModel
     * @return
     */
    @RequestMapping(value = "/api/memberOrder/updateOrderGetedIntegral", method = RequestMethod.POST)
    ResponseData updateOrderGetedIntegral(@RequestBody OrderModel orderModel);
    /**
     * 根据订单编号获取订单详情
     * @param orderNo
     * @param sysCompanyId
     * @param brandId
     * @return
     */
    @RequestMapping(value = "/api/memberOrder/queryOrderDetailByOrderNo", method = RequestMethod.POST)
    ResponseData<List<OrderDetailVo>> queryOrderDetailVoByOrderNo(@RequestParam("orderNo") String orderNo, @RequestParam("sysCompanyId") Long sysCompanyId, @RequestParam("brandId") Long brandId);

}
